@@ -1,6 +1,6 @@
 /*
   eXosip - This is the eXtended osip library.
-  Copyright (C) 2002,2003,2004,2005,2006,2007  Aymeric MOIZARD  - jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   eXosip is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,8 +29,7 @@
 #include <time.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -62,40 +61,42 @@ extern "C"
  * argument.
  *
  *
+ * @param excontext    eXosip_t instance.
  * @param message   Pointer for the SIP request to build.
  * @param method    request method. (like "MESSAGE" or "PING"...)
  * @param to        SIP url for callee.
  * @param from      SIP url for caller.
  * @param route     Route header for request. (optional)
  */
-  int eXosip_message_build_request (osip_message_t ** message, const char *method,
-                                    const char *to, const char *from,
-                                    const char *route);
+  int eXosip_message_build_request (struct eXosip_t *excontext, osip_message_t ** message, const char *method, const char *to, const char *from, const char *route);
 
 /**
  * Send an request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param message          SIP request to send.
  */
-  int eXosip_message_send_request (osip_message_t * message);
+  int eXosip_message_send_request (struct eXosip_t *excontext, osip_message_t * message);
 
 /**
  * Build answer for a request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param tid             id of transaction.
  * @param status          status for SIP answer to build.
  * @param answer          The SIP answer to build.
  */
-  int eXosip_message_build_answer (int tid, int status, osip_message_t ** answer);
+  int eXosip_message_build_answer (struct eXosip_t *excontext, int tid, int status, osip_message_t ** answer);
 
 /**
  * Send answer for a request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param tid             id of transaction.
  * @param status          status for SIP answer to send.
  * @param answer          The SIP answer to send. (default will be sent if NULL)
  */
-  int eXosip_message_send_answer (int tid, int status, osip_message_t * answer);
+  int eXosip_message_send_answer (struct eXosip_t *excontext, int tid, int status, osip_message_t * answer);
 
 /** @} */
 
@@ -103,5 +104,4 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
 #endif
