@@ -1,6 +1,6 @@
 /*
   eXosip - This is the eXtended osip library.
-  Copyright (C) 2002,2003,2004,2005,2006,2007  Aymeric MOIZARD  - jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   eXosip is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,8 +31,7 @@
 #include <time.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -59,38 +58,41 @@ extern "C"
 /**
  * Build a default OPTIONS message.
  * 
+ * @param excontext    eXosip_t instance.
  * @param options   Pointer for the SIP request to build.
  * @param to        SIP url for callee.
  * @param from      SIP url for caller.
  * @param route     Route header for INVITE. (optional)
  */
-  int eXosip_options_build_request (osip_message_t ** options, const char *to,
-                                    const char *from, const char *route);
+  int eXosip_options_build_request (struct eXosip_t *excontext, osip_message_t ** options, const char *to, const char *from, const char *route);
 
 /**
  * Send an OPTIONS request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param options          SIP OPTIONS message to send.
  */
-  int eXosip_options_send_request (osip_message_t * options);
+  int eXosip_options_send_request (struct eXosip_t *excontext, osip_message_t * options);
 
 /**
  * Build answer for an OPTIONS request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param tid             id of OPTIONS transaction.
  * @param status          status for SIP answer to build.
  * @param answer          The SIP answer to build.
  */
-  int eXosip_options_build_answer (int tid, int status, osip_message_t ** answer);
+  int eXosip_options_build_answer (struct eXosip_t *excontext, int tid, int status, osip_message_t ** answer);
 
 /**
  * Send answer for an OPTIONS request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param tid             id of OPTIONS transaction.
  * @param status          status for SIP answer to send.
  * @param answer          The SIP answer to send. (default will be sent if NULL)
  */
-  int eXosip_options_send_answer (int tid, int status, osip_message_t * answer);
+  int eXosip_options_send_answer (struct eXosip_t *excontext, int tid, int status, osip_message_t * answer);
 
 /** @} */
 
@@ -98,7 +100,5 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
 #endif
-
 #endif
