@@ -1,6 +1,6 @@
 /*
   eXosip - This is the eXtended osip library.
-  Copyright (C) 2002,2003,2004,2005,2006,2007  Aymeric MOIZARD  - jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   eXosip is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,8 +31,7 @@
 #include <time.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -57,6 +56,7 @@ extern "C"
 /**
  * build publication for a user. (PUBLISH request)
  * 
+ * @param excontext    eXosip_t instance.
  * @param message   returned published request.
  * @param to        SIP url for callee.
  * @param from      SIP url for caller.
@@ -66,21 +66,16 @@ extern "C"
  * @param ctype     Content-Type of body.
  * @param body     body for publication.
  */
-  int eXosip_build_publish (osip_message_t ** message,
-                            const char *to,
-                            const char *from,
-                            const char *route,
-                            const char *event,
-                            const char *expires,
-                            const char *ctype, const char *body);
+  int eXosip_build_publish (struct eXosip_t *excontext, osip_message_t ** message, const char *to, const char *from, const char *route, const char *event, const char *expires, const char *ctype, const char *body);
 
 /**
  * Send an Publication Message (PUBLISH request).
  * 
+ * @param excontext    eXosip_t instance.
  * @param message is a ready to be sent publish message .
  * @param to the aor of the publish request 
  */
-  int eXosip_publish (osip_message_t * message, const char *to);
+  int eXosip_publish (struct eXosip_t *excontext, osip_message_t * message, const char *to);
 
 
 /** @} */
@@ -89,7 +84,5 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
 #endif
-
 #endif
