@@ -1,6 +1,6 @@
 /*
   eXosip - This is the eXtended osip library.
-  Copyright (C) 2002,2003,2004,2005,2006,2007  Aymeric MOIZARD  - jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   eXosip is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,8 +29,7 @@
 #include <time.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 
@@ -59,39 +58,54 @@ extern "C"
 /**
  * Build initial REGISTER request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param from      SIP url for caller.
  * @param proxy     Proxy used for registration.
  * @param contact   Contact address. (optional)
  * @param expires   The expires value for registration.
  * @param reg       The SIP request to build.
  */
-  int eXosip_register_build_initial_register(const char *from, const char *proxy,
-					     const char *contact, int expires,
-					     osip_message_t **reg);
+  int eXosip_register_build_initial_register (struct eXosip_t *excontext, const char *from, const char *proxy, const char *contact, int expires, osip_message_t ** reg);
+
+/**
+ * Build initial REGISTER request with qvalue for contact.
+ * 
+ * @param excontext    eXosip_t instance.
+ * @param from      SIP url for caller.
+ * @param proxy     Proxy used for registration.
+ * @param contact   Contact address. (optional)
+ * @param expires   The expires value for registration.
+ * @param qvalue    The qvalue value for contact header.
+ * @param reg       The SIP request to build.
+ */
+  int eXosip_register_build_initial_register_withqvalue (struct eXosip_t *excontext, const char *from, const char *proxy, const char *contact, int expires, const char *qvalue, osip_message_t ** reg);
 
 /**
  * Build a new REGISTER request for an existing registration.
  * 
+ * @param excontext    eXosip_t instance.
  * @param rid       A unique identifier for the registration context
  * @param expires   The expires value for registration.
  * @param reg       The SIP request to build.
  */
-  int eXosip_register_build_register(int rid, int expires, osip_message_t **reg);
+  int eXosip_register_build_register (struct eXosip_t *excontext, int rid, int expires, osip_message_t ** reg);
 
 /**
  * Send a REGISTER request for an existing registration.
  * 
+ * @param excontext    eXosip_t instance.
  * @param rid       A unique identifier for the registration context
  * @param reg       The SIP request to build. (NULL for default REGISTER)
  */
-  int eXosip_register_send_register(int rid, osip_message_t *reg);
+  int eXosip_register_send_register (struct eXosip_t *excontext, int rid, osip_message_t * reg);
 
 /**
  * Remove existing registration without sending REGISTER.
  * 
+ * @param excontext    eXosip_t instance.
  * @param rid       A unique identifier for the registration context
  */
-  int eXosip_register_remove (int rid);
+  int eXosip_register_remove (struct eXosip_t *excontext, int rid);
 
 /** @} */
 
@@ -99,5 +113,4 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
 #endif
