@@ -1,6 +1,6 @@
 /*
   eXosip - This is the eXtended osip library.
-  Copyright (C) 2002,2003,2004,2005,2006,2007  Aymeric MOIZARD  - jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   eXosip is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,8 +29,7 @@
 #include <time.h>
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -54,27 +53,35 @@ extern "C"
  * @{
  */
 
-  typedef enum eXosip_ss
-  {
+/**
+ * Structure for subscription status
+ * @enum eXosip_ss
+ */
+  enum eXosip_ss {
     EXOSIP_SUBCRSTATE_UNKNOWN,    /**< unknown subscription-state */
     EXOSIP_SUBCRSTATE_PENDING,    /**< pending subscription-state */
     EXOSIP_SUBCRSTATE_ACTIVE,     /**< active subscription-state */
     EXOSIP_SUBCRSTATE_TERMINATED  /**< terminated subscription-state */
-  } eXosip_ss_t;
+  };
 
-  typedef enum eXosip_ss_reason
-  {
+/**
+ * Structure for subscription reason
+ * @enum eXosip_ss_reason
+ */
+  enum eXosip_ss_reason {
     DEACTIVATED,                 /**< deactivated for subscription-state */
     PROBATION,                   /**< probation for subscription-state */
     REJECTED,                    /**< rejected for subscription-state */
     TIMEOUT,                     /**< timeout for subscription-state */
     GIVEUP,                      /**< giveup for subscription-state */
     NORESOURCE                   /**< noresource for subscription-state */
-  } eXosip_ss_reason_t;
+  };
 
-
-  typedef enum eXosip_ss_status
-  {
+/**
+ * Structure for notification status
+ * @enum eXosip_ss_status
+ */
+  enum eXosip_ss_status {
     EXOSIP_NOTIFY_UNKNOWN,   /**< unknown state for subscription */
     EXOSIP_NOTIFY_PENDING,   /**< subscription not yet accepted */
     EXOSIP_NOTIFY_ONLINE,    /**< online status */
@@ -85,14 +92,14 @@ extern "C"
     EXOSIP_NOTIFY_ONTHEPHONE,/**< on the phone status */
     EXOSIP_NOTIFY_OUTTOLUNCH,/**< out to lunch status */
     EXOSIP_NOTIFY_CLOSED     /**< closed status */
-  } eXosip_ss_status_t;
-
+  };
 
 #ifndef MINISIZE
 
 /**
  * Build a default initial SUBSCRIBE request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param subscribe Pointer for the SIP request to build.
  * @param to        SIP url for callee.
  * @param from      SIP url for caller.
@@ -100,40 +107,41 @@ extern "C"
  * @param event     Event header for SUBSCRIBE.
  * @param expires   Expires header for SUBSCRIBE.
  */
-  int eXosip_subscribe_build_initial_request (osip_message_t ** subscribe,
-                                              const char *to, const char *from,
-                                              const char *route, const char *event,
-                                              int expires);
+  int eXosip_subscribe_build_initial_request (struct eXosip_t *excontext, osip_message_t ** subscribe, const char *to, const char *from, const char *route, const char *event, int expires);
 
 /**
  * Send an initial SUBSCRIBE request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param subscribe          SIP SUBSCRIBE message to send.
  */
-  int eXosip_subscribe_send_initial_request (osip_message_t * subscribe);
+  int eXosip_subscribe_send_initial_request (struct eXosip_t *excontext, osip_message_t * subscribe);
 
 /**
  * Build a default new SUBSCRIBE message.
  * 
+ * @param excontext    eXosip_t instance.
  * @param did      identifier of the subscription.
  * @param sub      Pointer for the SIP request to build.
  */
-  int eXosip_subscribe_build_refresh_request (int did, osip_message_t ** sub);
+  int eXosip_subscribe_build_refresh_request (struct eXosip_t *excontext, int did, osip_message_t ** sub);
 
 /**
  * Send a new SUBSCRIBE request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param did          identifier of the subscription.
  * @param sub          SIP SUBSCRIBE message to send.
  */
-  int eXosip_subscribe_send_refresh_request (int did, osip_message_t * sub);
+  int eXosip_subscribe_send_refresh_request (struct eXosip_t *excontext, int did, osip_message_t * sub);
 
 /**
  * Remove outgoing subscription context.
  * 
+ * @param excontext    eXosip_t instance.
  * @param did          identifier of the subscription.
  */
-  int eXosip_subscribe_remove (int did);
+  int eXosip_subscribe_remove (struct eXosip_t *excontext, int did);
 
 /** @} */
 
@@ -146,59 +154,60 @@ extern "C"
 /**
  * Build answer for an SUBSCRIBE request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param tid             id of SUBSCRIBE transaction.
  * @param status          status for SIP answer to build.
  * @param answer          The SIP answer to build.
  */
-  int eXosip_insubscription_build_answer (int tid, int status,
-                                          osip_message_t ** answer);
+  int eXosip_insubscription_build_answer (struct eXosip_t *excontext, int tid, int status, osip_message_t ** answer);
 
 /**
  * Send answer for an SUBSCRIBE request.
  * 
+ * @param excontext    eXosip_t instance.
  * @param tid             id of SUBSCRIBE transaction.
  * @param status          status for SIP answer to send.
  * @param answer          The SIP answer to send. (default will be sent if NULL)
  */
-  int eXosip_insubscription_send_answer (int tid, int status,
-                                         osip_message_t * answer);
+  int eXosip_insubscription_send_answer (struct eXosip_t *excontext, int tid, int status, osip_message_t * answer);
 
 /**
  * Build a request within subscription.
  * 
+ * @param excontext    eXosip_t instance.
  * @param did             id of incoming subscription.
  * @param method          request method to build.
  * @param request         The SIP request to build.
  */
-  int eXosip_insubscription_build_request (int did, const char *method,
-                                           osip_message_t ** request);
+  int eXosip_insubscription_build_request (struct eXosip_t *excontext, int did, const char *method, osip_message_t ** request);
 
 /**
  * Build a NOTIFY request within subscription.
  * 
+ * @param excontext    eXosip_t instance.
  * @param did                  id of incoming subscription.
  * @param subscription_status  subscription status (pending, active, terminated)
  * @param subscription_reason  subscription reason
  * @param request              The SIP request to build.
  */
-  int eXosip_insubscription_build_notify (int did, int subscription_status,
-                                          int subscription_reason,
-                                          osip_message_t ** request);
+  int eXosip_insubscription_build_notify (struct eXosip_t *excontext, int did, int subscription_status, int subscription_reason, osip_message_t ** request);
 
 /**
  * Send a request within subscription.
  * 
+ * @param excontext    eXosip_t instance.
  * @param did             id of incoming subscription.
  * @param request         The SIP request to send.
  */
-  int eXosip_insubscription_send_request (int did, osip_message_t * request);
+  int eXosip_insubscription_send_request (struct eXosip_t *excontext, int did, osip_message_t * request);
 
 /**
  * Remove incoming subscription context.
  * 
+ * @param excontext    eXosip_t instance.
  * @param did          identifier of the subscription.
  */
-  int eXosip_insubscription_remove (int did);
+  int eXosip_insubscription_remove (struct eXosip_t *excontext, int did);
 
 
 #endif
@@ -209,5 +218,4 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
 #endif
